@@ -39,11 +39,11 @@ def login(username, password, api):
         click.secho("Password must be provided", err=True, fg="red")
         raise SystemExit(1)
 
-    payload = {"user_email": username, "user_password": password, "additionalProp1": {}}
+    payload = {"user_email": username, "user_password": password}
     api = sdk.AuthApi(api)
     try:
-        token = api.auth_local_login(body=payload)
-        click.echo(token["refresh_token"])
+        token = api.auth_external_login(body=payload)
+        click.echo(token.access_token)
     except ApiException as err:
         click.secho("Login was not successful", err=True, fg="red")
         click.secho(f"Reason: {str(err)}", err=True, fg="red")
@@ -72,9 +72,6 @@ def get_providers(skip, take, json, platform):
 
 
 @apis.command()
-@click.option(
-    "--show-secret", "-s", is_flag=True, default=False, help="Shows API secrets."
-)
 @click.option("--skip", default=0, type=int, help="Skip N API keys.")
 @click.option("--take", default=128, type=int, help="Take N API keys.")
 @click.option(
@@ -84,24 +81,24 @@ def get_providers(skip, take, json, platform):
     default=False,
     help="Outputs a JSON instead of a table.",
 )
-@syntropy_platform
-def get_api_keys(show_secret, skip, take, json, platform):
+@syntropy_api
+def get_api_keys(skip, take, json, api):
     """List all API keys.
 
     API keys are being used by the endpoint agent to connect to the syntropy platform.
 
     By default this command will retrieve up to 128 API keys. You can use --take parameter to get more keys.
     """
-    keys = platform.platform_api_key_index(skip=skip, take=take)["data"]
+
+    api = sdk.ApiKeysApi(api)
+    keys = api.index_api_key(skip=skip, take=take).data
+    keys = [key.to_dict() for key in keys]
 
     fields = [
-        ("ID", "api_key_id"),
-        ("User ID", "user_id"),
-        ("Key ID", "api_key_id"),
-        ("Key Name", "api_key_name"),
+        ("ID", "api_key_id", lambda x: int(x)),
+        ("Name", "api_key_name"),
         ("Is Suspended", "api_key_is_suspended", lambda x: x and "Yes" or "No"),
         ("Status", "api_key_status", lambda x: x and "Ok" or "Err"),
-        ("Secret", "api_key_secret", lambda x: show_secret and x or "-"),
         ("Created At", "api_key_created_at"),
         ("Updated At", "api_key_updated_at"),
         ("Expires At", "api_key_valid_until"),
@@ -117,16 +114,20 @@ def get_api_keys(show_secret, skip, take, json, platform):
     default=(datetime.now() + timedelta(days=30)).strftime("%Y-%m-%d %H:%M:%S"),
 )
 @click.option("--suspended", "-s", is_flag=True, help="Create a suspended API key.")
-@syntropy_platform
-def create_api_key(name, suspended, expires, platform):
-    """Create a API key for endpoint agent."""
+@syntropy_api
+def create_api_key(name, suspended, expires, api):
+    """Create a API key for endpoint agent.
+
+    NOTE: Be sure to remember the API key as it will be only available as a result of this command.
+    """
     body = {
         "api_key_name": name,
         "api_key_is_suspended": suspended,
         "api_key_valid_until": expires,
     }
-    result = platform.platform_api_key_create(body=body)
-    click.echo(result["data"]["api_key_id"])
+    api = sdk.ApiKeysApi(api)
+    result = api.create_api_key(body=body)
+    click.echo(result.data.api_key_secret)
 
 
 def confirm_deletion(name, id):
@@ -146,26 +147,28 @@ def confirm_deletion(name, id):
     default=False,
     help="Forces to delete all matching networks.",
 )
-@syntropy_platform
-def delete_api_key(name, id, yes, platform):
+@syntropy_api
+def delete_api_key(name, id, yes, api):
     """Delete API key either by name or by id. If there are multiple names - please use id."""
     if name is None and id is None:
         click.secho("Either API key name or id must be specified.", err=True, fg="red")
         raise SystemExit(1)
 
+    api = sdk.ApiKeysApi(api)
+
     if id is None:
-        keys = platform.platform_api_key_index(filter=f"api_key_name:{name}")["data"]
+        keys = api.index_api_key(filter=f"api_key_name:{name}").data
         for key in keys:
-            if not yes and not confirm_deletion(key["api_key_name"], key["api_key_id"]):
+            if not yes and not confirm_deletion(key.api_key_name, key.api_key_id):
                 continue
 
-            platform.platform_api_key_destroy(key["api_key_id"])
+            api.delete_api_key(key.api_key_id)
             click.secho(
-                f"Deleted API key: {key['api_key_name']} (id={key['api_key_id']}).",
+                f"Deleted API key: {key.api_key_name} (id={key.api_key_id}).",
                 fg="green",
             )
     else:
-        platform.platform_api_key_destroy(id)
+        api.delete_api_key(id)
         click.secho(f"Deleted API key: id={id}.", fg="green")
 
 
@@ -548,9 +551,7 @@ def get_topology(json, platform):
 
     fields = [
         ("Network name", "network_name"),
-        ("Network type", "network_type"),
         ("Network ID", "network_id"),
-        ("Gateway ID", "agent_gateway_id"),
         ("N# of endpoints", "network_agents_count"),
         ("N# of connections", "network_agent_connections_count"),
     ]
@@ -565,6 +566,7 @@ def get_topology(json, platform):
     help="Filter connections by network name or ID.",
 )
 @click.option("--id", default=None, type=int, help="Filter endpoints by ID.")
+@click.option("--name", default=None, type=int, help="Filter endpoints by ID or name.")
 @click.option("--skip", default=0, type=int, help="Skip N connections.")
 @click.option("--take", default=42, type=int, help="Take N connections.")
 @click.option(
@@ -581,17 +583,15 @@ def get_topology(json, platform):
     help="Outputs a JSON instead of a table.",
 )
 @syntropy_platform
-def get_connections(network, id, skip, take, show_services, json, platform):
+def get_connections(network, id, name, skip, take, show_services, json, platform):
     """Retrieves network connections.
 
     Connection service status is added to the end of the service name with the following possible symbols:
 
     \b
-    ^ - Connection is online.
-    ! - There was an error establishing the connection
-    # - Connection is offline
-    * - Connection is in warning state
-    ~ - Connection is being established
+    ^ - Service is online.
+    ! - There was an error exposing the service
+    ~ - Service is in PENDING state
     ? - Unknown state
 
     By default this command will retrieve up to 42 connections. You can use --take parameter to get more connections.
@@ -608,8 +608,10 @@ def get_connections(network, id, skip, take, show_services, json, platform):
                 f"networks[]:{','.join(str(net['network_id']) for net in networks)}"
             )
 
+    if name:
+        filters.append(f"id|name:{name}")
     if id:
-        filters.append(f"id|name:{id}")
+        filters.append(f"agent_ids[]:{id}")
     connections = platform.platform_connection_index(
         filter=",".join(filters) if filters else None,
         skip=skip,
@@ -618,21 +620,22 @@ def get_connections(network, id, skip, take, show_services, json, platform):
     fields = [
         ("ID", "agent_connection_id"),
         ("Endpoint 1", ("agent_1", "agent_name")),
+        ("ID 1", ("agent_1", "agent_id")),
         ("IP 1", ("agent_1", "agent_public_ipv4")),
         ("Endpoint 2", ("agent_2", "agent_name")),
+        ("ID 2", ("agent_2", "agent_id")),
         ("IP 2", ("agent_2", "agent_public_ipv4")),
         ("Status", "agent_connection_status"),
-        ("Network name", "network_name"),
-        ("Network type", "network_type"),
-        ("Network ID", ("network", "network_id")),
-        ("Gateway ID", "agent_gateway_id"),
-        ("Created At", "agent_connection_created_at"),
-        ("Modified At", "agent_connection_modified_at"),
-        ("SDN Policy ID", "agent_sdn_policy_id"),
-        ("Link Tag", "agent_connection_link_tag"),
-        ("Last Handshake", "agent_connection_last_handshake"),
-        ("TX total", "agent_connection_tx_bytes_total"),
-        ("RX total", "agent_connection_rx_bytes_total"),
+        ("Modified At", "agent_connection_updated_at"),
+        (
+            "Networks",
+            "networks",
+            lambda networks: ", ".join(
+                str(network.get("network_id", "-")) for network in networks
+            )
+            if networks
+            else "-",
+        ),
         ("Latency", "agent_connection_latency_ms"),
         ("Packet Loss", "agent_connection_packet_loss"),
     ]
@@ -710,7 +713,6 @@ def create_connections(network, agents, use_names, json, platform):
         raise SystemExit(1)
 
     network = networks[0]["network_id"]
-    network_type = networks[0]["network_type"]
     if use_names:
         all_agents = platform.platform_agent_index(take=TAKE_MAX_ITEMS_PER_CALL)["data"]
         agents = find_by_name(all_agents, agents, "agent")
@@ -723,38 +725,35 @@ def create_connections(network, agents, use_names, json, platform):
             click.secho("Invalid agent id", err=True, fg="red")
             raise SystemExit(1)
 
-    if network_type == sdk.NetworkType.POINT_TO_POINT:
-        if len(agents) == 0 or len(agents) % 2 != 0:
-            click.secho("Number of agents must be even.", err=True, fg="red")
-            raise SystemExit(1)
-        agents = list(zip(agents[:-1:2], agents[1::2]))
+    if len(agents) == 0 or len(agents) % 2 != 0:
+        click.secho("Number of agents must be even.", err=True, fg="red")
+        raise SystemExit(1)
+    agents = list(zip(agents[:-1:2], agents[1::2]))
 
     body = {
-        "network_id": network,
-        "agent_ids": agents,
+        "network_ids": [network],
+        "agent_ids": [{"agent_1_id": a, "agent_2_id": b} for a, b in agents],
         "network_update_by": sdk.NetworkGenesisType.SDK,
     }
-    connections = platform.platform_connection_create(
-        body=body, update_type=sdk.UpdateType.APPEND_NEW
-    )["data"]
+    result = platform.platform_connection_create_p2p(body=body)
 
-    fields = [
-        ("Connection ID", "agent_connection_id"),
-        ("Endpoint 1 ID", "agent_1_id"),
-        ("Endpoint 1 WG", "agent_wg_1_id"),
-        ("Endpoint 2 ID", "agent_2_id"),
-        ("Endpoint 2 WG", "agent_wg_2_id"),
-        ("Network ID", "network_id"),
-    ]
-    print_table(connections, fields, to_json=json)
+    if "errors" in result:
+        for error in result["errors"]:
+            click.secho(f"Error: {error.get('message')}", err=True, fg="red")
 
 
 @apis.command()
-@click.argument("id", type=int)
+@click.argument("endpoint-1", type=int)
+@click.argument("endpoint-2", type=int)
 @syntropy_platform
-def delete_connection(id, platform):
+def delete_connection(endpoint_1, endpoint_2, platform):
     """Delete a connection."""
-    platform.platform_connection_destroy(id)
+    platform.platform_connection_destroy(
+        {
+            "agent_1_id": endpoint_1,
+            "agent_2_id": endpoint_2,
+        }
+    )
 
 
 @apis.command()
@@ -784,12 +783,10 @@ def get_networks(network, show_secret, skip, take, json, platform):
     )["data"]
 
     fields = [
+        ("ID", "network_id"),
         ("Organization ID", "organization_id"),
         ("User ID", "user_id"),
-        ("Agent Gateway ID", "agent_gateway_id"),
-        ("Network ID", "network_id"),
         ("Network Name", "network_name"),
-        ("Network Type", "network_type"),
         ("Network Topology", ("network_metadata", "network_type")),
         ("Network Secret", "network_key", lambda x: show_secret and x or "-"),
         (
@@ -807,19 +804,6 @@ def get_networks(network, show_secret, skip, take, json, platform):
 
 @apis.command()
 @click.argument("name")
-@click.option(
-    "--network-type",
-    default=sdk.NetworkType.POINT_TO_POINT,
-    help="Low level network type.",
-    hidden=True,
-)
-@click.option(
-    "--gateway-id",
-    default=0,
-    type=int,
-    help="Endpoint ID to use as gateway for GATEWAY network type.",
-    hidden=True,
-)
 @click.option(
     "--topology",
     default=sdk.MetadataNetworkType.P2P,
@@ -833,9 +817,7 @@ def get_networks(network, show_secret, skip, take, json, platform):
     hidden=True,
 )
 @syntropy_platform
-def create_network(
-    name, network_type, topology, gateway_id, disable_sdn_connections, platform
-):
+def create_network(name, topology, disable_sdn_connections, platform):
     """Create a network.
 
     Possible network topologies are P2P, P2M, MESH. The network topology is mainly used for
@@ -856,10 +838,6 @@ def create_network(
         syntropyctl create-network MyNetworkName --topology MESH
 
     """
-    if network_type not in ALLOWED_NETWORK_TYPES:
-        click.secho(f"Network type {network_type} is not allowed.", err=True, fg="red")
-        raise SystemExit(1)
-
     topology = topology.upper() if topology else topology
     if topology is not None and topology not in ALLOWED_NETWORK_TOPOLOGIES:
         click.secho(f"Network topology {topology} is not allowed.", err=True, fg="red")
@@ -867,8 +845,6 @@ def create_network(
 
     body = {
         "network_name": name,
-        "network_type": network_type,
-        "agent_gateway_id": gateway_id,
         "network_disable_sdn_connections": disable_sdn_connections,
         "network_metadata": {
             "network_created_by": sdk.NetworkGenesisType.SDK,
